@@ -11,22 +11,16 @@ impl<T> InnerSlot<T> {
         Box::leak(Box::new(Self { value: None, pool }))
     }
 
-    #[allow(mutable_transmutes)]
-    #[allow(clippy::mut_from_ref)]
-    fn as_mut(&self) -> &mut Self {
-        unsafe { std::mem::transmute(self) }
-    }
-
     pub(crate) fn pool(&self) -> &'static InnerPool<T> {
         self.pool
     }
 
-    pub(crate) fn clear_value(&self) {
-        self.as_mut().value = None;
+    pub(crate) fn clear_value(&mut self) {
+        self.value = None;
     }
 
-    pub(crate) fn take_value(&self) -> T {
-        self.as_mut().value.take().unwrap()
+    pub(crate) fn take_value(&mut self) -> T {
+        self.value.take().unwrap()
     }
 
     pub(crate) fn value(&self) -> &Option<T> {
